import random
import os
from scan_manager import ScanManager

# Generic variables
branch = os.environ.get("BRANCH", "main")
primary_trigger_scan = os.environ.get("PRIMARY_TRIGGER_SCAN", "true").lower()
custom_id = random.randbytes(16).hex()

# cbctl and twistcli variables
scan_image_list = os.environ.get("SCAN_IMAGE_LIST")

primary_workflow_file = "scan.yml"
primary_inputs = {
    "SCAN_IMAGE_LIST_INPUT": scan_image_list,
    "CUSTOM_ID": custom_id,
}

# BlackDuck variables
scan_image_list = os.environ.get("SCAN_IMAGE_LIST")
blackduck_trigger_scan = os.environ.get("BLACKDUCK_TRIGGER_SCAN", "false").lower()
blackduck_project_group = os.environ.get("BLACKDUCK_PROJECT_GROUP", "CB Cloud (CBC)")
blackduck_project_name = os.environ.get("BLACKDUCK_PROJECT_NAME", "ESG-Product-Security-Test")
blackduck_project_version = os.environ.get("BLACKDUCK_PROJECT_VERSION", "unknown")
blackduck_detect_tools = os.environ.get("BLACKDUCK_DETECT_TOOLS", "CONTAINER_SCAN")
blackduck_excluded_tools = os.environ.get(
    "BLACKDUCK_EXCLUDED_TOOLS",
    "BINARY_SCAN,DETECTOR,SIGNATURE_SCAN,IMPACT_ANALYSIS,DOCKER,BAZEL,IAC_SCAN,THREAT_INTEL",
)

blackduck_workflow_file = "blackduck.yml"
blackduck_inputs = {
    "BLACKDUCK_PROJECT_GROUP": blackduck_project_group,
    "BLACKDUCK_PROJECT_NAME": blackduck_project_name,
    "BLACKDUCK_PROJECT_VERSION": blackduck_project_version,
    "BLACKDUCK_TARGET": scan_image_list,
    "BLACKDUCK_DETECT_TOOLS": blackduck_detect_tools,
    "BLACKDUCK_EXCLUDED_TOOLS": blackduck_excluded_tools,
    "CUSTOM_ID": custom_id,
}

# Build Integrity variables
bi_trigger_scan = os.environ.get("BI_TRIGGER_SCAN", "false").lower()
bi_file_to_scan = os.environ.get("FILE_TO_SCAN")
bi_pkg_name = os.environ.get("PKG_NAME", "test")
bi_pkg_ver = os.environ.get("PKG_VER", "0.0.0")

bi_repo_name = "SED/ESG-ProdSec-Build-Integrity-Test"
bi_workflow_file = "scan.yml"
bi_inputs = {
    "FILE_TO_SCAN": bi_file_to_scan,
    "PKG_NAME": bi_pkg_name,
    "PKG_VER": bi_pkg_ver,
    "RL_CHECK": "true",
    "CLAMAV_CHECK": "true",
    "CUSTOM_ID": custom_id
}

if __name__ == "__main__":
    if blackduck_trigger_scan == "true":
        primary_trigger_scan = "false"
        blackduck_scan_manager = ScanManager(branch=branch)

        blackduck_scan_manager.initiate_scan(
            blackduck_workflow_file,
            blackduck_inputs,
        )

    if bi_trigger_scan == "true":
        primary_trigger_scan = "false"
        if branch == "main":
            # default branch here is master
            branch = "master"
        bi_scan_manager = ScanManager(repo_name=bi_repo_name, branch=branch)
        bi_scan_manager.initiate_scan(
            bi_workflow_file,
            bi_inputs
        )

    if primary_trigger_scan == "true":
        primary_scan_manager = ScanManager(branch=branch)

        primary_scan_manager.initiate_scan(
            primary_workflow_file,
            primary_inputs
        )
